---
title: Towards computer assisted modeling
theme: beige
revealOptions:
    transition: 'slide'
    slideNumber: true
---

# Towards computer assisted modeling

#### (*Me:*) Romain Reuillon
#### (*The team:*) Paul Chapron, Guillaume Cherel, Clémentine Cottineau, Mathieu Leclaire, Denise Pumain, Sebastien Rey-Coyrehourcq, Clara Schmitt

---

## Computer assisted modeling

<p style="text-align:center">Build a general framework and algorithms to guide the modeling process.</p><br/>

Make the modeling process:
  * *traceable*: understand what choices were made,
  * *reproducible*: recompute the reason why they were made,
  * *reusable*: study alternative choices.

----

### Descriptive models

<p style="text-align:center">Design/evaluate a theory involving causal effects through its capacity to (re-)produce some patterns/data.</p><br/>
<img style="height:300px" src=img/descriptive_model.svg>

----

### Model evaluation

How to assess: 
  * the *sufficiency* of the mechanisms ?
  * the *necessity* of the mechanisms ?
  * the *uniqueness* of the mechanisms ?

---

## Sufficiency

----

### Free parameters, example of Simpop Local

<img style="height:400px" src=img/slocal.png>

<p style="text-align:center">No empirical evidence for the parameters.</p>

----

### The usual approach

<p style="text-align:center">Use a classical design of experiment.</b> <br/>


<img style="height:400px" src=img/sobol.jpg>

----

### Limits

 * It produces a huge quantity of data.
 * It transform a problem into a data-mining problem.
 * The parameter space is mostly left unexplored due to the curse of dimensionality.

----

### Reverse approach

<img style="height:400px" src=img/guided.jpg>

<p style="text-align:center">From *output* values to *parameter* values.</b>

----

### Formalising the expectations

<img style="height:500px" src=img/slocal_fitness.png>

----

### Genetic algorithm as a calibration algorithm

<img style="height:500px" src=img/ga.png>

----

### Calibration method

*Genome*: 6 parameters of the model

*Fitness*: 3 descriptors of the quality of the simulated dynamic.

<br/>

Necessary extensions:
  * distributed computing
  * auto-adaptative strategy to handle stochasticity

----

### Results

<img style="height:450px" src=img/simpopcalibrated.svg>

<p style="text-align:center">No compromise between the 3 objectives.</p>

----

### Evaluation approach

* Would not have been found using a direct method.

<img style="height:300px" src=img/hv.svg>

The method is tractable (even for ABMs):
  * Handles stochasticity: 100x gain.
  * Support for distributed computing: 1000x gain.

----

### Conclusion

How to assess: 
  * the sufficiency of the mechanisms ✓
  * the necessity of the mechanisms ?
  * the uniqueness of the mechanisms ?

---

## Necessity

----

### A new algorithm

* To detect if a parameter is useful: it impacts the capacity of the model to produce plausible outcomes.

* To better constrain the parameter ranges.

* As an indirect way to detect if some of the mechanisms are expandable. 


----

### Objective

<p style="text-align:center">Hundreds of calibrations</p>

<img style="height:450px" src=img/PdiffusionZ.pdf.png>

----

<img style="height:500px" src=img/profil_algo.svg>

----

### The profile algorithm

Compute the best of calibration for hundreds of values along the definition domain of a parameter.

<br/>

The method is tractable (even for ABMs):
  * Converges almost as fast a single calibration.
  * Handles stochasticity: 100x gain.
  * Support for distributed computing: 1000x gain.

----

### Interpretation 


<img style="height:500px" src=img/profil_interpretation.svg>

----

### Results

<img style="height:500px" src=img/PdiffusionZ.pdf.png>


----

### Results

<img style="height:500px" src=img/InnovationLife.pdf.png>

----

### Conclusion

How to assess: 
  * the sufficiency of the mechanisms ✓
  * the necessity of the mechanisms ✓
  * the uniqueness of the mechanisms ?

---

## Uniqueness

----

<img style="height:300px" src=img/descriptive_model.svg>

<br/>
<p style="text-align:center">Automate the confrontation of alternative hypothesis / mechanisms.</p>

----

<img style="height:400px" src=img/model_familly.svg>

----

### What we are running after?

<img style="height:400px" src=img/familly_pareto.svg>

----

<img style="height:450px" src=img/marius_complexification.png>

<br/>

<p style="text-align:center">64 models</p>

----

### Example of concurent hypotheses

<div id="left" style="width:40%"><img style="height:350px;padding-top:50px" src="./img/system_mec.png"></div>

<div id="right" style="width:55%">
<p>Exchange mechanism:</p>
<ul>
 <li>Market based</li>
 <li>Centrally planned</li>
</ul>
<br/>
<p>City growth mechanism:</p>
<ul>
 <li>Purely inter-urban interactions</li>
 <li>Influenced by environmental situation</li>
</ul>
</div>

----

### Model familly calibration

Compute the best set of parameters for all 64 models.

<img style="height:400px" src=img/varius_big.png>

[http://shiny.parisgeo.cnrs.fr/VARIUS/](http://shiny.parisgeo.cnrs.fr/VARIUS/)

----

### Calibration method

*Algorithm principle*: reuse the good parameters found on one model to calibrate on the others.

<br/>

The method is tractable (even for ABMs):
  * as fast (faster ??) as calibrating a single model.
  * Handles stochasticity: 100x gain.
  * Support for distributed computing: 1000x gain.

----

### Conclusion

How to assess: 
  * the sufficiency of the mechanisms ✓
  * the necessity of the mechanisms ✓
  * the uniqueness of the mechanisms (≈) ✓

----

### Alternative aproach

<p style="text-align:center">All these methods are based on an *a priori* mesurment of the quality.</p>

<img style="height:300px" src=img/narowed.jpg>

<br/>

<p style="text-align:center">Can we propose an alternative aproach to evaluation?</p>

---

## Pattern search

----

<img style="height:500px" src=img/pse_algo.svg>

----

<img style="height:400px" src=img/hitmap.svg>

<p style="text-align:center;padding-top:10px">The inputs producing rare patterns have high fitness values.</p>

----

<img style="height:500px" src=img/flockingvolumediscovered.svg>

----

<img style="height:500px" src=img/flockingpatterns.png>

----

<img style="height:600px" src=img/pse_marius.png>

----

### Interpretation

* All expected/observed patterns are produced: the model is generic enough.<br/><br/>

* Unexepected patterns are found:
 * aberations: better constrain the model,
 * predictions: test them.

---

## OpenMOLE

<a href="www.openmole.org">www.openmole.org</a>

----

<img style="height:500px" src=img/openmole.png>


----

### Browser interface

<img style="height:400px" src=img/openmole_web.png>

----

### High level language

<pre style="brush: scala"><code>val optimisation =
  SteadyStateEvolution(
    algorithm =
      NSGA2(
        mu = 1000,
        genome = Seq(x in (0.0, 1.0), y in (0.0, 1.0)),
        objectives = Seq(o1, o2)
      ),
    evaluation = model,
    termination = 10 hours
  )

val cluster = SLURMEnvironment("login", "cluster.univ.org")

(optimisation on cluster)</code></pre>


---

## Where are we going now?

----

### New methods

* Generalized model hypothesis exploration:
  * multi-modeling calibration in OpenMOLE,
  * propose a framework for the exporation of large space of mechanisms (billions of candidate models).
* Find all the precursors of a pattern.
* Find the discontinuities.

----

### New applications

Collaboration:
 * with academics,
 * with private sector.

<br/>

Regular OpenMOLE training: 23 Novembre 2017, at ISC-PIF
See: [www.openmole.org](www.openmole.org) -> Training

----

### Exemple OpenMOLE + SimPLU (IGN)

<video height="400px" autoplay controls>
  <source src="img/capture_visuPSE.webm" type="video/webm">
</video>

[simplu2.openmole.org](http://simplu2.openmole.org)

----

### Dynamicity

<p style="text-align:center">Public/private partnership: 3 partners, 2M euros.</p>

<img style="height:200px;margin-top:50px;margin-bottom:50px" src=img/ForCity-Banner.png>

<p style="text-align:center">Simulation plateform to evaluate the consequences of the relocalisation of work offices.</p>

----

### Monetizing OpenMOLE

Making OpenMOLE sustainable by *creating an entreprise* to monetize it as a *free and open-source software*.

<br/>

* OpenMOLE is a great tool for research, but it grows. 
* Quality will be impacted without funding engineers to maintain/develop it.

----

### Monetizing OpenMOLE

<img style="height:400px" src=img/openmole_doc.png>


----

### Open-data founding protocol: Datawards


<img style="height:400px" src=img/datawards.png>

---

# Thank you

